=======
circuit
=======

Minimal native Python library for building and working with logical circuits.

.. image:: https://badge.fury.io/py/circuit.svg
   :target: https://badge.fury.io/py/circuit
   :alt: PyPI version and link.

Package Installation and Usage
------------------------------
The package is available on PyPI::

    python -m pip install circuit

The library can be imported in the usual way::

    import circuit
    from circuit import *
